@@ -71,11 +71,15 @@ def rebot(app: Application, robot_options_and_args: Tuple[str, ...]) -> None:
     )
 
     try:
-        profile = (
-            load_robot_config_from_path(*config_files)
-            .combine_profiles(*(app.config.profiles or []), verbose_callback=app.verbose)
-            .evaluated()
+        profile = load_robot_config_from_path(*config_files).combine_profiles(
+            *(app.config.profiles or []), verbose_callback=app.verbose
         )
+        if profile.env:
+            for k, v in profile.env.items():
+                os.environ[k] = str(v)
+                app.verbose(lambda: f"Set environment variable {k} to {v}")
+        profile = profile.evaluated()
+
     except (TypeError, ValueError) as e:
         raise click.ClickException(str(e)) from e
 
@@ -90,11 +94,6 @@ def rebot(app: Application, robot_options_and_args: Tuple[str, ...]) -> None:
     except (TypeError, ValueError) as e:
         raise click.ClickException(str(e)) from e
 
-    if profile.env:
-        for k, v in profile.env.items():
-            os.environ[k] = v
-            app.verbose(lambda: f"Set environment variable {k} to {v}")
-
     app.verbose(
         lambda: "Executing rebot with the following options:\n    "
         + " ".join(f'"{o}"' for o in (options + list(robot_options_and_args)))
